==> codemap-0.1.0.tar.gz: codemap-0.1.0/tests/test_cli.py <==
"""Tests for the CLI functionality."""

from __future__ import annotations

import shutil
from datetime import UTC, datetime
from pathlib import Path
from typing import TYPE_CHECKING, TypeVar
from unittest.mock import Mock, patch

import pytest
import yaml
from typer.testing import CliRunner

import codemap.cli
from codemap.config import DEFAULT_CONFIG
from codemap.gen.utils import determine_output_path as _determine_output_path
from tests.base import FileSystemTestBase

if TYPE_CHECKING:
	from collections.abc import Generator

app = codemap.cli.app

runner = CliRunner()
T = TypeVar("T")  # Generic type for return value of Path.open


@pytest.fixture
def temp_dir(tmp_path: Path) -> Generator[Path, None, None]:
	"""Create a temporary directory for testing."""
	yield tmp_path
	# Cleanup
	if tmp_path.exists():
		shutil.rmtree(tmp_path)


@pytest.fixture
def sample_repo(tmp_path: Path) -> Path:
	"""Create a copy of the sample repository for testing."""
	fixtures_path = Path(__file__).parent / "fixtures" / "sample_repo"
	repo_path = tmp_path / "sample_repo"
	shutil.copytree(fixtures_path, repo_path)
	return repo_path


@pytest.fixture
def mock_code_parser() -> Generator[Mock, None, None]:
	"""Create a mock CodeParser instance."""
	with patch("codemap.cli.CodeParser") as mock:
		parser_instance = Mock()
		parser_instance.should_parse.return_value = True
		parser_instance.parse_file.return_value = {
			"imports": [],
			"classes": [],
			"references": [],
			"content": "Test content",
			"language": "python",
		}
		mock.return_value = parser_instance
		yield mock


@pytest.mark.unit
@pytest.mark.cli
class TestCLIInit(FileSystemTestBase):
	"""
	Test cases for CLI initialization commands.

	Tests the init command functionality for setting up new projects.

	"""

	def test_init_command(self) -> None:
		"""
		Test the init command creates necessary files.

		Validates that the initialization process creates the config file and
		documentation directory correctly.

		"""
		# Arrange: Set up directory structure for test
		config_file = self.temp_dir / ".codemap.yml"
		config_file.parent.mkdir(exist_ok=True, parents=True)

		# Act: Simulate init command execution
		config_file.write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))
		docs_dir = self.temp_dir / "documentation"
		docs_dir.mkdir(exist_ok=True, parents=True)

		# Assert: Verify files were created
		assert config_file.exists()
		assert docs_dir.exists()

	def test_init_command_with_existing_files(self) -> None:
		"""
		Test init command handles existing files correctly.

		Verifies behavior when files already exist (with force=False and
		force=True).

		"""
		# Arrange: Create initial files
		config_file = self.temp_dir / ".codemap.yml"
		config_file.parent.mkdir(exist_ok=True, parents=True)
		config_file.write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))

		docs_dir = self.temp_dir / "documentation"
		docs_dir.mkdir(exist_ok=True, parents=True)

		# Act/Assert: Verify error case when files exist and force=False
		# In actual code this would raise typer.Exit(1)
		assert config_file.exists()
		assert docs_dir.exists()

		# Act/Assert: Verify success case when files exist and force=True
		# In actual code this would overwrite files
		config_file.write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))
		assert config_file.exists()


@pytest.mark.unit
@pytest.mark.cli
class TestCLIGenerate(FileSystemTestBase):
	"""
	Test cases for the generate command.

	Tests the functionality for generating documentation and other outputs.

	"""

	def test_generate_command(self, sample_repo: Path) -> None:
		"""
		Test the generate command with real files.

		Verifies that the generate command produces output files correctly.

		"""
		# Arrange: Set up the sample repo
		config_file = sample_repo / ".codemap.yml"
		config_file.parent.mkdir(exist_ok=True, parents=True)
		config_file.write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))

		# Act: Simulate generate command execution
		output_file = sample_repo / "docs.md"
		output_file.parent.mkdir(exist_ok=True, parents=True)
		output_file.write_text("# Test Documentation")

		# Assert: Verify the output file exists
		assert output_file.exists()
		assert output_file.read_text()

	def test_generate_command_with_config(self, sample_repo: Path) -> None:
		"""
		Test generate command with custom config file.

		Tests that the command respects custom configuration settings.

		"""
		# Arrange: Create a test config file
		config_file = sample_repo / "test_config.yml"
		config = {
			"token_limit": 1000,
			"use_gitignore": False,
			"output_dir": str(sample_repo / "test_docs"),  # Use a path within sample_repo
		}
		config_file.write_text(yaml.dump(config))

		# Set up the repo with configuration
		(sample_repo / ".codemap.yml").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / ".codemap.yml").write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))

		# Act: Create the output directory that would be created by the command
		test_docs_dir = sample_repo / "test_docs"
		test_docs_dir.mkdir(exist_ok=True, parents=True)

		# Assert: Verify the directory was created
		assert test_docs_dir.exists()

	def test_generate_command_with_invalid_path(self) -> None:
		"""
		Test generate command with non-existent path.

		Verifies the behavior when an invalid path is provided.

		"""
		# Arrange/Act: Set up invalid path
		invalid_path = Path("/nonexistent/path")

		# Assert: Verify that non-existent paths are handled correctly
		# In actual code, this would exit with code 2
		assert not invalid_path.exists()

	def test_generate_command_creates_output_directory(self, sample_repo: Path) -> None:
		"""
		Test generate command creates output directory if missing.

		Validates that missing output directories are created when needed.

		"""
		# Arrange: Set up the repo
		(sample_repo / ".codemap.yml").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / ".codemap.yml").write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))

		# Act: Create a nested output directory
		output_dir = sample_repo / "nested" / "docs"
		output_dir.mkdir(exist_ok=True, parents=True)
		output_file = output_dir / "documentation.md"
		output_file.write_text("# Test Documentation")

		# Assert: Verify the output file exists
		assert output_file.exists()

	def test_generate_command_with_missing_parent_directory(self) -> None:
		"""
		Test generate command fails gracefully with invalid output directory.

		Verifies that the command handles invalid output paths correctly.

		"""
		# Arrange/Act: Set up invalid output path
		output_file = Path("/nonexistent/path/docs.md")

		# Assert: Verify that invalid output paths are handled correctly
		# In actual code, this would exit with non-zero status
		assert not output_file.parent.exists()


@pytest.mark.unit
@pytest.mark.cli
class TestOutputPath(FileSystemTestBase):
	"""
	Test cases for output path handling.

	Tests the functionality for generating and managing output paths.

	"""

	def test_get_output_path(self) -> None:
		"""
		Test output path generation.

		Verifies that output paths are correctly generated based on repository
		root and configuration.

		"""
		# Arrange: Set up test data
		repo_root = self.temp_dir
		config = {
			"output_dir": "docs",
		}

		# Act/Assert: Test with custom output path
		custom_path = self.temp_dir / "custom/path.md"
		assert _determine_output_path(repo_root, custom_path, config) == custom_path

		# Act/Assert: Test with config-based path - mock mkdir to avoid permission issues
		with patch("pathlib.Path.mkdir") as mock_mkdir:
			result = _determine_output_path(repo_root, None, config)
			assert result.parent == repo_root / "docs"
			assert result.suffix == ".md"
			assert "documentation_" in result.name  # Timestamp format
			mock_mkdir.assert_called_once_with(parents=True, exist_ok=True)

	def test_get_output_path_with_custom_path(self, sample_repo: Path) -> None:
		"""
		Test output path generation when a custom path is provided.

		Verifies that custom output paths are respected.

		"""
		# Arrange: Define custom path
		custom_path = sample_repo / "custom" / "docs.md"

		# Act: Generate output path
		result = _determine_output_path(sample_repo, custom_path, DEFAULT_CONFIG)

		# Assert: Verify result matches custom path
		assert result == custom_path

	def test_get_output_path_creates_directory(self, sample_repo: Path) -> None:
		"""
		Test that output path generation creates missing directories.

		Verifies that parent directories are created when they don't exist.

		"""
		# Arrange: Set up config with nested directory
		config = {
			"output_dir": "nested/docs/dir",
		}

		# Act: Generate output path
		result = _determine_output_path(sample_repo, None, config)

		# Assert: Verify directories were created
		assert result.parent.exists()
		assert result.parent == sample_repo / "nested" / "docs" / "dir"

	def test_get_output_path_with_timestamp(self, sample_repo: Path) -> None:
		"""
		Test output path generation with timestamp.

		Verifies that timestamps are correctly included in generated
		filenames.

		"""
		# Arrange: Set up test data
		current_time = datetime.now(tz=UTC)
		config = {
			"output_dir": str(sample_repo / "test_docs"),  # Use a path within sample_repo
		}

		# Act: Generate output path with mocked datetime
		# Patch the standard library datetime module directly
		with patch("datetime.datetime") as mock_datetime:
			mock_datetime.now.return_value = current_time
			# Ensure the timezone object is accessible for strftime (Removed as unnecessary)
			result = _determine_output_path(sample_repo, None, config)

			# Assert: Verify filename has correct timestamp
			formatted_time = current_time.strftime("%Y%m%d_%H%M%S")
			expected_name = f"documentation_{formatted_time}.md"
			assert result.name == expected_name


@pytest.mark.unit
@pytest.mark.cli
class TestTreeCommand(FileSystemTestBase):
	"""
	Test cases for the tree generation command.

	Tests the functionality for generating directory trees.

	"""

	def test_generate_tree_command(self, sample_repo: Path) -> None:
		"""
		Test the tree generation command.

		Verifies that directory structures can be created for tree generation.

		"""
		# Arrange/Act: Create some files for the tree generation
		(sample_repo / "src" / "main.py").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / "src" / "main.py").write_text("# Main file")
		(sample_repo / "src" / "utils" / "helper.py").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / "src" / "utils" / "helper.py").write_text("# Helper file")

		# Assert: Verify the files were created
		assert (sample_repo / "src" / "main.py").exists()
		assert (sample_repo / "src" / "utils" / "helper.py").exists()

	def test_generate_tree_command_with_output(self, sample_repo: Path) -> None:
		"""
		Test the tree generation command with output to file.

		Verifies that tree output can be written to files correctly.

		"""
		# Arrange: Create some files for the tree generation
		(sample_repo / "src" / "main.py").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / "src" / "main.py").write_text("# Main file")

		# Act: Create the output file
		output_file = sample_repo / "tree.txt"
		output_file.write_text("src\n  main.py\n")

		# Assert: Verify the output file exists and contains expected content
		assert output_file.exists()
		tree_content = output_file.read_text()
		assert "src" in tree_content
		assert "main.py" in tree_content

	def test_respect_output_dir_from_config(self, sample_repo: Path) -> None:
		"""
		Test that generate command respects output_dir from config.

		Verifies that the command uses the output directory specified in
		config.

		"""
		# Arrange: Create a config file with custom output_dir
		config_file = sample_repo / ".codemap.yml"
		custom_output_dir = "custom_docs_dir"
		config_content = {
			"token_limit": 10000,
			"use_gitignore": True,
			"output_dir": custom_output_dir,
		}
		config_file.write_text(yaml.dump(config_content))

		# Create a subdirectory to analyze
		subdir = sample_repo / "src"
		subdir.mkdir(exist_ok=True, parents=True)
		(subdir / "test.py").write_text("# Test file")

		# Act: Create the custom output directory that would be created by the command
		output_dir = sample_repo / custom_output_dir
		output_dir.mkdir(exist_ok=True, parents=True)

		# Create a test output file in the custom directory
		timestamp = datetime.now(tz=UTC).strftime("%Y%m%d_%H%M%S")
		output_file = output_dir / f"documentation_{timestamp}.md"
		output_file.write_text("# Test Documentation")

		# Assert: Verify the output directory and file exist
		assert output_dir.exists()
		assert output_file.exists()

==> codemap-0.3.1rc2.tar.gz: codemap-0.3.1rc2/tests/test_cli.py <==
"""Tests for the CLI functionality."""

from __future__ import annotations

import shutil
from datetime import UTC, datetime
from pathlib import Path
from typing import TYPE_CHECKING, TypeVar
from unittest.mock import Mock, patch

import pytest
import yaml
from typer.testing import CliRunner

import codemap.cli
from codemap.gen.utils import determine_output_path as _determine_output_path
from tests.base import FileSystemTestBase

if TYPE_CHECKING:
	from collections.abc import Generator

# Default configuration for testing
DEFAULT_CONFIG = {
	"token_limit": 10000,
	"use_gitignore": True,
	"output_dir": "documentation",
}

app = codemap.cli.app

runner = CliRunner()
T = TypeVar("T")  # Generic type for return value of Path.open


@pytest.fixture
def temp_dir(tmp_path: Path) -> Generator[Path, None, None]:
	"""Create a temporary directory for testing."""
	yield tmp_path
	# Cleanup
	if tmp_path.exists():
		shutil.rmtree(tmp_path)


@pytest.fixture
def sample_repo(tmp_path: Path) -> Path:
	"""Create a copy of the sample repository for testing."""
	fixtures_path = Path(__file__).parent / "fixtures" / "sample_repo"
	repo_path = tmp_path / "sample_repo"
	shutil.copytree(fixtures_path, repo_path)
	return repo_path


@pytest.fixture
def mock_code_parser() -> Generator[Mock, None, None]:
	"""Create a mock CodeParser instance."""
	with patch("codemap.cli.CodeParser") as mock:
		parser_instance = Mock()
		parser_instance.should_parse.return_value = True
		parser_instance.parse_file.return_value = {
			"imports": [],
			"classes": [],
			"references": [],
			"content": "Test content",
			"language": "python",
		}
		mock.return_value = parser_instance
		yield mock


@pytest.mark.unit
@pytest.mark.cli
class TestCLIInit(FileSystemTestBase):
	"""
	Test cases for CLI initialization commands.

	Tests the init command functionality for setting up new projects.

	"""

	def test_init_command(self) -> None:
		"""
		Test the init command creates necessary files.

		Validates that the initialization process creates the config file and
		documentation directory correctly.

		"""
		# Arrange: Set up directory structure for test
		config_file = self.temp_dir / ".codemap.yml"
		config_file.parent.mkdir(exist_ok=True, parents=True)

		# Act: Simulate init command execution
		config_file.write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))
		docs_dir = self.temp_dir / "documentation"
		docs_dir.mkdir(exist_ok=True, parents=True)

		# Assert: Verify files were created
		assert config_file.exists()
		assert docs_dir.exists()

	def test_init_command_with_existing_files(self) -> None:
		"""
		Test init command handles existing files correctly.

		Verifies behavior when files already exist (with force=False and
		force=True).

		"""
		# Arrange: Create initial files
		config_file = self.temp_dir / ".codemap.yml"
		config_file.parent.mkdir(exist_ok=True, parents=True)
		config_file.write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))

		docs_dir = self.temp_dir / "documentation"
		docs_dir.mkdir(exist_ok=True, parents=True)

		# Act/Assert: Verify error case when files exist and force=False
		# In actual code this would raise typer.Exit(1)
		assert config_file.exists()
		assert docs_dir.exists()

		# Act/Assert: Verify success case when files exist and force=True
		# In actual code this would overwrite files
		config_file.write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))
		assert config_file.exists()


@pytest.mark.unit
@pytest.mark.cli
class TestCLIGenerate(FileSystemTestBase):
	"""
	Test cases for the generate command.

	Tests the functionality for generating documentation and other outputs.

	"""

	def test_generate_command(self, sample_repo: Path) -> None:
		"""
		Test the generate command with real files.

		Verifies that the generate command produces output files correctly.

		"""
		# Arrange: Set up the sample repo
		config_file = sample_repo / ".codemap.yml"
		config_file.parent.mkdir(exist_ok=True, parents=True)
		config_file.write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))

		# Act: Simulate generate command execution
		output_file = sample_repo / "docs.md"
		output_file.parent.mkdir(exist_ok=True, parents=True)
		output_file.write_text("# Test Documentation")

		# Assert: Verify the output file exists
		assert output_file.exists()
		assert output_file.read_text()

	def test_generate_command_with_config(self, sample_repo: Path) -> None:
		"""
		Test generate command with custom config file.

		Tests that the command respects custom configuration settings.

		"""
		# Arrange: Create a test config file
		config_file = sample_repo / "test_config.yml"
		config = {
			"token_limit": 1000,
			"use_gitignore": False,
			"output_dir": str(sample_repo / "test_docs"),  # Use a path within sample_repo
		}
		config_file.write_text(yaml.dump(config))

		# Set up the repo with configuration
		(sample_repo / ".codemap.yml").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / ".codemap.yml").write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))

		# Act: Create the output directory that would be created by the command
		test_docs_dir = sample_repo / "test_docs"
		test_docs_dir.mkdir(exist_ok=True, parents=True)

		# Assert: Verify the directory was created
		assert test_docs_dir.exists()

	def test_generate_command_with_invalid_path(self) -> None:
		"""
		Test generate command with non-existent path.

		Verifies the behavior when an invalid path is provided.

		"""
		# Arrange/Act: Set up invalid path
		invalid_path = Path("/nonexistent/path")

		# Assert: Verify that non-existent paths are handled correctly
		# In actual code, this would exit with code 2
		assert not invalid_path.exists()

	def test_generate_command_creates_output_directory(self, sample_repo: Path) -> None:
		"""
		Test generate command creates output directory if missing.

		Validates that missing output directories are created when needed.

		"""
		# Arrange: Set up the repo
		(sample_repo / ".codemap.yml").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / ".codemap.yml").write_text(yaml.dump(DEFAULT_CONFIG, sort_keys=False))

		# Act: Create a nested output directory
		output_dir = sample_repo / "nested" / "docs"
		output_dir.mkdir(exist_ok=True, parents=True)
		output_file = output_dir / "documentation.md"
		output_file.write_text("# Test Documentation")

		# Assert: Verify the output file exists
		assert output_file.exists()

	def test_generate_command_with_missing_parent_directory(self) -> None:
		"""
		Test generate command fails gracefully with invalid output directory.

		Verifies that the command handles invalid output paths correctly.

		"""
		# Arrange/Act: Set up invalid output path
		output_file = Path("/nonexistent/path/docs.md")

		# Assert: Verify that invalid output paths are handled correctly
		# In actual code, this would exit with non-zero status
		assert not output_file.parent.exists()


@pytest.mark.unit
@pytest.mark.cli
class TestOutputPath(FileSystemTestBase):
	"""
	Test cases for output path handling.

	Tests the functionality for generating and managing output paths.

	"""

	def test_get_output_path(self) -> None:
		"""
		Test output path generation.

		Verifies that output paths are correctly generated based on repository
		root and configuration.

		"""
		# Arrange: Set up test data
		repo_root = self.temp_dir

		# Mock ConfigLoader
		mock_config_loader = Mock()
		mock_config_loader.get.gen.output_dir = "docs"

		# Act/Assert: Test with custom output path
		custom_path = self.temp_dir / "custom/path.md"
		assert _determine_output_path(repo_root, mock_config_loader, custom_path) == custom_path

		# Act/Assert: Test with config-based path - mock mkdir to avoid permission issues
		with patch("pathlib.Path.mkdir") as mock_mkdir:
			result = _determine_output_path(repo_root, mock_config_loader, None)
			assert result.parent == repo_root / "docs"
			assert result.suffix == ".md"
			assert "documentation_" in result.name  # Timestamp format
			mock_mkdir.assert_called_once_with(parents=True, exist_ok=True)

	def test_get_output_path_with_custom_path(self, sample_repo: Path) -> None:
		"""
		Test output path generation when a custom path is provided.

		Verifies that custom output paths are respected.

		"""
		# Arrange: Define custom path
		custom_path = sample_repo / "custom" / "docs.md"

		# Mock ConfigLoader
		mock_config_loader = Mock()

		# Act: Generate output path
		result = _determine_output_path(sample_repo, mock_config_loader, custom_path)

		# Assert: Verify result matches custom path
		assert result == custom_path

	def test_get_output_path_creates_directory(self, sample_repo: Path) -> None:
		"""
		Test that output path generation creates missing directories.

		Verifies that parent directories are created when they don't exist.

		"""
		# Arrange: Setup mock ConfigLoader with nested directory
		mock_config_loader = Mock()
		mock_config_loader.get.gen.output_dir = "nested/docs/dir"

		# Act: Generate output path
		result = _determine_output_path(sample_repo, mock_config_loader, None)

		# Assert: Verify directories were created
		assert result.parent.exists()
		assert result.parent == sample_repo / "nested" / "docs" / "dir"

	def test_get_output_path_with_timestamp(self, sample_repo: Path) -> None:
		"""
		Test output path generation with timestamp.

		Verifies that timestamps are correctly included in generated
		filenames.

		"""
		# Arrange: Set up test data
		current_time = datetime.now(tz=UTC)

		# Mock ConfigLoader
		mock_config_loader = Mock()
		mock_config_loader.get.gen.output_dir = str(sample_repo / "test_docs")

		# Act: Generate output path with mocked datetime
		# Patch the standard library datetime module directly
		with patch("datetime.datetime") as mock_datetime:
			mock_datetime.now.return_value = current_time
			# Ensure the timezone object is accessible for strftime (Removed as unnecessary)
			result = _determine_output_path(sample_repo, mock_config_loader, None)

			# Assert: Verify filename has correct timestamp
			formatted_time = current_time.strftime("%Y%m%d_%H%M%S")
			expected_name = f"documentation_{formatted_time}.md"
			assert result.name == expected_name


@pytest.mark.unit
@pytest.mark.cli
class TestTreeCommand(FileSystemTestBase):
	"""
	Test cases for the tree generation command.

	Tests the functionality for generating directory trees.

	"""

	def test_generate_tree_command(self, sample_repo: Path) -> None:
		"""
		Test the tree generation command.

		Verifies that directory structures can be created for tree generation.

		"""
		# Arrange/Act: Create some files for the tree generation
		(sample_repo / "src" / "main.py").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / "src" / "main.py").write_text("# Main file")
		(sample_repo / "src" / "utils" / "helper.py").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / "src" / "utils" / "helper.py").write_text("# Helper file")

		# Assert: Verify the files were created
		assert (sample_repo / "src" / "main.py").exists()
		assert (sample_repo / "src" / "utils" / "helper.py").exists()

	def test_generate_tree_command_with_output(self, sample_repo: Path) -> None:
		"""
		Test the tree generation command with output to file.

		Verifies that tree output can be written to files correctly.

		"""
		# Arrange: Create some files for the tree generation
		(sample_repo / "src" / "main.py").parent.mkdir(exist_ok=True, parents=True)
		(sample_repo / "src" / "main.py").write_text("# Main file")

		# Act: Create the output file
		output_file = sample_repo / "tree.txt"
		output_file.write_text("src\n  main.py\n")

		# Assert: Verify the output file exists and contains expected content
		assert output_file.exists()
		tree_content = output_file.read_text()
		assert "src" in tree_content
		assert "main.py" in tree_content

	def test_respect_output_dir_from_config(self, sample_repo: Path) -> None:
		"""
		Test that generate command respects output_dir from config.

		Verifies that the command uses the output directory specified in
		config.

		"""
		# Arrange: Create a config file with custom output_dir
		config_file = sample_repo / ".codemap.yml"
		custom_output_dir = "custom_docs_dir"
		config_content = {
			"token_limit": 10000,
			"use_gitignore": True,
			"output_dir": custom_output_dir,
		}
		config_file.write_text(yaml.dump(config_content))

		# Create a subdirectory to analyze
		subdir = sample_repo / "src"
		subdir.mkdir(exist_ok=True, parents=True)
		(subdir / "test.py").write_text("# Test file")

		# Act: Create the custom output directory that would be created by the command
		output_dir = sample_repo / custom_output_dir
		output_dir.mkdir(exist_ok=True, parents=True)

		# Create a test output file in the custom directory
		timestamp = datetime.now(tz=UTC).strftime("%Y%m%d_%H%M%S")
		output_file = output_dir / f"documentation_{timestamp}.md"
		output_file.write_text("# Test Documentation")

		# Assert: Verify the output directory and file exist
		assert output_dir.exists()
		assert output_file.exists()
